# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [Unreleased]

### Added

- Frontpage now detects if the user is logged in.
  - If the user is logged in, the frontpage will show a user's books button instead of login.
- Added an indicator for currently online users.
  - The indicator is shown in the sidebar on the right side of each page preview if another user is currently viewing the page.
  - On hover, it shows the email of the user.
- Profile page has some functionality now.
  - User may change their email (requires email verification).
  - User may change their password (requires email verification).
  - User may set default values for the different tools.
- Removed the global navbar.
  - Opted to use the sidebar for main navigation.
- Clicking on the header of a snip now gives more information about the snip.
  - This includes: snip type, width, height, and creation date.
- Text tool now has an alignment submenu item.
  - Allows aligning the snippet to top, center, bottom, left, center, or right of the page.
- Image placement tool now has an alignment submenu item.
  - Allows aligning the snippet to top, center, bottom, left, center, or right of the page.
- Page move tool now has auto-fit width and height buttons.
  - Automatically fits the page to the width or height of your screen.
- Users are now notified on bad connections.
- Added validation for env parameters.
  - Catch missing env parameters early!
- Added BackgroundTypes database service.
- Added dedicated server for email sending.
- Maintenance page handler, if the app is down you will know now.

### Changed

- We now partially use app router instead of pages router.
  - Smaller bundle size.
  - Faster page transitions.
- Split up codebase into multiple independent packages.
  - Easier testing.
  - Easier development.
  - Significant change!
- Changelog now follows the Keep a Changelog format.

### Fixed

- Fixed canvas render width/height issue on devices with devicePixelRatio != 1.
  - See [#74](https://gitlab.gwdg.de/irp/snip/-/issues/74).
- Verify/Reset Password emails look better now (CSS added).
- Grid view overflow on long book names now shows as ellipsis.
- Fixed page flickering on resize.


## [1.5.3] 

### Changed

- Refactored email functions.
- Graceful quit for prebuild script.
- Upgraded from Buster to Bookworm Docker image.

### Fixed

- Fixed a bug in the server-side render pipeline (textBaseline was wrong).
  - See [#2343](https://github.com/Automattic/node-canvas/issues/2343).


## [1.5.2]

### Fixed

- Unauthorized screen layout was broken.
- Refactor upload endpoint.
- Updated API Usage docs.
  - Updated example scripts for upload.

### Added

- Test mode for testing uploads.


## [1.5.1]

### Added

- Page search in viewer is now fully functional.
  - Search is case insensitive.
  - Allows for modifiers (snip types, page numbers, etc.).
  - See docs for more info.

### Fixed

- Reset password screen alignment was broken.
- Verify email screen alignment was broken.
- Overflow was always shown in Chrome yielding a white line at the bottom of the page.

## 1.5.0

### Added

- Interaction mode (small eye icon).
  - Allows copying and pasting texts.
  - Allows interacting with snips that have event handlers.
    - E.g. on_click.
    - Currently, no snips have feedback, but the framework is there.

### Changed

- Refactor of overlay modules (related to above).
- Text edit tool uses the new overlay modules.


## [1.4.4]

### Changed

- Refactor of tools to reduce some code duplication.
- Split the developer docs into deployment and developer guides.
  - Also fixed some old docs.
  - Added to developer guides:
    - Snip documentation.
    - Tool documentation.
  - Parsing of links was broken if they ended with `.md` or `.mdx`.

### Added

- Docker entrypoint now automatically checks for database migration.

## [1.4.3]

### Fixed

- Fixed bug with draw interpolation.
  - On canvas leave, the line would be drawn to the left top corner due to inserting null values.
  - Do not draw null values.
- Logout not handled gracefully.


## [1.4.2] 

### Added

- Read-only mode.
  - Tools are dynamically picked by access level.
  - See new field in `/book/:id/edit/access`.

### Fixed

- Strange scroll behavior in edit page.
- Fixed a bug where the snips to place were not updated when a user adds a new snip.
- Overlay sometimes persisted on page change.
- Re-enabled old live updates for drawing (might be disabled again depending on performance).

## [1.4.1] 

### Fixed

- Fixed some alignment problems with the frontpage on mobile devices.

### Added

- Added pointer events instead of mouse events.
  - Should fix some problems with touch devices.
  - Applies to the resizer, move tool, draw tool, and text tool.

## [1.4.0] 

### Added

- We have a frontpage now! It explains the features of the app and helps new users get started.
- Pen line smoothing.
  - New slider to adjust smoothing.
  - Ramer-Douglas-Peucker algorithms for simplification of the polyline with additional splines for drawing.
- User settings.
  - Settings are saved for each user in the database.
  - Settings are synced across devices.
    - Sync happens on page reload or focus change to avoid confusion when using multiple tabs.
  - Settings include:
    - Zoom levels.
    - Font, font size, line height, line wrap.
    - Pen color, pen size.
- Added background gradient to page viewer.

### Fixed

- Fixed a bug where the page was setup multiple times by the worker.

### Changed

- Fonts are now dynamically injected into the page.
  - Makes the process of adding fonts easier.
  - Has no effect on the user.

## [1.3.4] 

### Fixed

- Chrome range slider looked different than other browsers.
- Zoom rounding error.
- Tab change sometimes produced an empty page, forcing rerender on activity change.

## [1.3.3]

### Added

- Added modal to configure PDF download.
  - Option to download with page numbers.
  - Option to only download selected pages.

### Fixed

- Adjusted styling of page number in the sidebar of the book viewer.
- Fixed bug with resizer using manual input or mouse wheel.
- Show finished books by default.
- Fixed tool not changing anymore in textarea on typing "p" or "m".

## [1.3.2]

### Added

- New book browser.
  - Folder sorting.
    - Drag and drop to sort folders.
  - Book sorting.
    - Sort by title, last modified, date added, and number of pages.

## [1.3.1]

### Added

- Image compression.
  - Added script to compress all images (see `scripts` folder).
  - Added auto image compression for file uploads.
  - WebP support for images.
- Maintenance mode.
  - Redirects all requests to `maintenance.html` page.
  - Started by putting `COMMAND=maintenance` in `.env` file.


## old

There are no changelogs for versions before 1.3.1.



[Unreleased]: https://gitlab.gwdg.de/irp/snip/-/compare/v1.5.3...HEAD
[1.5.3]: https://gitlab.gwdg.de/irp/snip/-/compare/v1.5.2...v1.5.3
[1.5.2]: https://gitlab.gwdg.de/irp/snip/-/compare/v1.5.1...v1.5.2
[1.5.1]: https://gitlab.gwdg.de/irp/snip/-/compare/v1.5.0...v1.5.1
[1.5.0]: https://gitlab.gwdg.de/irp/snip/-/compare/v1.4.4...v1.5.0
[1.4.4]: https://gitlab.gwdg.de/irp/snip/-/compare/v1.4.3...v1.4.4
[1.4.3]: https://gitlab.gwdg.de/irp/snip/-/compare/v1.4.2...v1.4.3
[1.4.2]: https://gitlab.gwdg.de/irp/snip/-/compare/v1.4.1...v1.4.2
[1.4.1]: https://gitlab.gwdg.de/irp/snip/-/compare/v1.4.0...v1.4.1
[1.4.0]: https://gitlab.gwdg.de/irp/snip/-/compare/v1.3.4...v1.4.0
[1.3.4]: https://gitlab.gwdg.de/irp/snip/-/compare/v1.3.3...v1.3.4
[1.3.3]: https://gitlab.gwdg.de/irp/snip/-/compare/v1.3.2...v1.3.3
[1.3.2]: https://gitlab.gwdg.de/irp/snip/-/compare/v1.3.1...v1.3.2
