"use server";

import { errorToMessage } from "lib/actions/errorToMessage";
import { getSessionAction } from "lib/session";
import { headers } from "next/headers";

import service from "@snip/database";
import { UserData } from "@snip/database/types";

async function _loginSubmitAction(
    prevState: { message: string; userData: UserData },
    formData: FormData,
): Promise<{ userData: UserData; message?: string }> {
    const rawForm = {
        email: formData.get("email") as string,
        password: formData.get("password") as string,
    };

    if (!rawForm.email || !rawForm.password) {
        throw Error("No Email or Password given!");
    }
    const success = await service.user.login(rawForm.email, rawForm.password);
    if (!success) {
        throw Error("Invalid Email or Password!");
    }
    const userData = await service.user.getByEmail(rawForm.email);
    if (!userData) {
        throw Error("Invalid Email or Password!");
    }

    // Save session
    const session = await getSessionAction();
    session.user = {
        id: userData.id,
        email_verified: userData.emailValidated,
        created: userData.created.getTime(),
    };
    await session.save();

    // In the background update the last login ip and time
    updateDatabaseLoginInfo(userData.id);
    // Success
    return { userData };
}

export const loginSubmitAction = errorToMessage(_loginSubmitAction);

async function updateDatabaseLoginInfo(userId: number) {
    const ip = headers().get("X-Forwarded-For");
    service.user.updateLoginInfo(userId, ip).catch((e) => {
        console.error("Failed to update login info", e);
    });
}
