"use client";
import type {
    BaseData,
    BaseView,
    BookData,
    PageData,
    SnipData,
} from "@snip/database/types";

import { EditorContextProvider } from "./context";
import Resizer from "./resizer";
import Sidebar from "./sidebar";
import { Toolbar } from "./tools/toolbar";
import { Viewer } from "./viewer";

export function EditorSinglePageNoSidebar({
    pageData,
}: {
    pageData: PageData;
}) {
    return (
        <EditorContextProvider
            book_id={pageData.book_id}
            pages={[pageData]}
            queuedSnips={[]}
        >
            <Toolbar />
            <Viewer />
        </EditorContextProvider>
    );
}

export function EditorSinglePage({
    bookData,
    pages,
    queuedSnips,
}: {
    bookData: BookData;
    pages: PageData[];
    queuedSnips: SnipData<BaseData, BaseView>[];
}) {
    return (
        <EditorContextProvider
            book_id={bookData.id}
            pages={pages}
            queuedSnips={queuedSnips}
        >
            <div
                id="the_editor"
                className="d-flex h-100"
                style={{
                    background:
                        "repeating-linear-gradient(45deg, $gray-100, transparent 20px, transparent 25px)",
                    backgroundColor: "var(--bs-body-bg)",
                }}
            >
                <Sidebar bookData={bookData} init_with_width={false} />
                <Resizer />
                <div className="position-relative">
                    <Toolbar />
                    <Viewer />
                </div>
            </div>
        </EditorContextProvider>
    );
}
