"use client";
import { useCallback, useEffect, useState } from "react";
import { Button, ButtonGroup } from "react-bootstrap";

import { PageData } from "@snip/database/types";

import { File_left, File_plus, File_right } from "./svgs";

import { usePagesContext } from "components/context/socket/usePagesContext";
import { useEditorContext } from "components/editor/context";

import styles from "./navigation.module.scss";

export default function PageSwitcher({ finished }: { finished: boolean }) {
    const { pagesArray: pages, createPage } = usePagesContext();
    const { activePageIds, setActivePageIds } = useEditorContext();

    const [boundaries, setBoundaries] = useState<{
        first: boolean;
        last: boolean;
    }>({ first: false, last: false });

    const updateBoundariesCheck = useCallback(
        (pagesData: PageData | PageData[]) => {
            if (!Array.isArray(pagesData)) {
                pagesData = [pagesData];
            }
            const page_numbers = pagesData.map((p) => p.page_number);
            const first = page_numbers.some((n) => n <= 0);
            const last = page_numbers.some((n) => n >= pages.length - 1);
            setBoundaries({ first, last });
        },
        [pages.length],
    );

    /** Increment the active page index by the given amount
     * i.e. -1 for previous, 1 for next
     * @param increment
     */
    const incrementPage = useCallback(
        (increment: number) => {
            const currentPages = activePageIds
                .map((id) => pages.filter((p) => p.id === id))
                .flat();

            const next_page_nums = currentPages.map(
                (p) => p.page_number + increment,
            );

            // Get next pages
            // only works if pages are sorted by page number
            const nextPages = next_page_nums.map((num) => {
                return pages[num];
            });

            const nextPageIds = nextPages.map((p) => p.id);

            setActivePageIds(nextPageIds);
        },
        [pages, activePageIds, setActivePageIds],
    );

    /** Initial check for boundaries */
    useEffect(() => {
        if (!pages) return;
        const pages_id = activePageIds
            .map((id) => pages.filter((p) => p.id === id))
            .flat();
        updateBoundariesCheck(pages_id);
    }, [activePageIds, pages, updateBoundariesCheck]);

    return (
        <div className={styles.pageSwitcher}>
            <ButtonGroup aria-label="Switcher">
                <Button
                    disabled={boundaries.first || activePageIds.length === 0}
                    onClick={() => incrementPage(-1)}
                    variant="outline-gray"
                >
                    <File_left width="25px" height="30px" alt="Prev" />
                </Button>
                <Button
                    disabled={boundaries.last || activePageIds.length === 0}
                    onClick={() => incrementPage(1)}
                    variant="outline-gray"
                >
                    <File_right width="25px" height="30px" alt="Next" />
                </Button>
            </ButtonGroup>
            <Button
                style={{ marginLeft: "10px" }}
                variant="outline-gray"
                onClick={async () => {
                    const newPage = await createPage();
                    setActivePageIds((prevIds) => {
                        prevIds.pop();
                        prevIds.unshift(newPage.id);
                        return [...prevIds];
                    });
                }}
                disabled={finished}
            >
                <File_plus width="25px" height="30px" alt="+" />
            </Button>
        </div>
    );
}
