import { Button, ButtonProps } from "react-bootstrap";
import OverlayTrigger from "react-bootstrap/OverlayTrigger";
import Tooltip from "react-bootstrap/Tooltip";
import { IconContext } from "react-icons/lib";
import { TbCaretRightFilled } from "react-icons/tb";

import styles from "./toggle.module.scss";

/** Button to toggle a tool
 */
export function ToolBtn({ children, ...props }: ButtonProps) {
    let className = styles.toggleBtn;
    if (props.className) {
        className += " " + props.className;
    }

    return (
        <Button variant="none" className={className} {...props}>
            {children}
        </Button>
    );
}

export function ExpandBtn({ active, ...props }: ButtonProps) {
    let className = styles.expandBtn;
    if (props.className) {
        className += " " + props.className;
    }

    return (
        <Button variant="none" className={className} active={active} {...props}>
            <TbCaretRightFilled />
        </Button>
    );
}

export function Toggle({
    label,
    icon,
    isActive,
    setActive,
    isExpanded,
    setExpanded,
    expandable = true,
    style = {},
}) {
    const renderTooltip = (props) => <Tooltip {...props}>{label}</Tooltip>;

    return (
        <IconContext.Provider
            value={{
                className: styles.icon,
            }}
        >
            <OverlayTrigger
                placement="right"
                overlay={renderTooltip}
                delay={{ show: 1000, hide: 400 }}
                transition={false}
            >
                <div className={styles.wrapper} style={style}>
                    <ToolBtn
                        active={isActive}
                        onClick={() => setActive(!isActive)}
                        onContextMenu={(e) => {
                            e.preventDefault();
                            if (!expandable) return;
                            setExpanded(!isExpanded);
                        }}
                    >
                        {icon}
                    </ToolBtn>
                    {expandable && (
                        <ExpandBtn
                            active={isExpanded}
                            onClick={() => setExpanded(!isExpanded)}
                            onContextMenu={(e) => {
                                e.preventDefault();
                                setExpanded(!isExpanded);
                            }}
                        />
                    )}
                </div>
            </OverlayTrigger>
        </IconContext.Provider>
    );
}
