"use client";

import { ReactNode, useMemo } from "react";

import { ToolComponents } from "./types";

/**
 * Provides the context for the a given
 * set of tools.
 *
 * For the tool specific context providers, see
 * the tool specific folder. E.g. `text`.
 *
 * @param contextProviders - An array of tool context providers.
 * @param overlayRect - The overlay rectangle.
 * @param setOverlayRect - A function to set the overlay rectangle.
 * @param children - The child components to render.
 *
 * @returns The context providers wrapped around the child components.
 */
export function ToolsContextProvider({
    contextProviders,

    children,
}: {
    contextProviders: ToolComponents["ContextProvider"][];

    children: ReactNode;
}) {
    return useMemo(() => {
        return contextProviders.toReversed().reduce((acc, Provider, i) => {
            if (!Provider) {
                return acc;
            }
            return <Provider key={i}>{acc}</Provider>;
        }, children);
    }, [children, contextProviders]);
}
