"use client";
import {
    createContext,
    Dispatch,
    SetStateAction,
    useContext,
    useState,
} from "react";

import { ToolContextProps } from "../types";

export interface DoodleContextI {
    // The current tool
    colorList: string[];
    setColorList: (colorList: string[]) => void;

    // Current color
    currentColor: string;
    currentColorIdx: number;
    setCurrentColorIdx: Dispatch<SetStateAction<number>>;
    // Pen size
    size: number;
    setSize: (size: number) => void;

    // Pen smoothing
    smoothing: number;
    setSmoothing: (smoothing: number) => void;
}

const DoodleToolContext = createContext<DoodleContextI>({
    colorList: ["#000000"],
    setColorList: () => {},

    currentColorIdx: 0,
    setCurrentColorIdx: () => {},
    currentColor: "#000000",

    size: 4,
    setSize: () => {},

    smoothing: 1,
    setSmoothing: () => {},
});

export function DoodleToolContextProvider({ children }: ToolContextProps) {
    // TODO: sync with database
    const [colorList, setColorList] = useState([
        "#000000",
        "#0000ff",
        "#ff0000",
        "#00ff00",
    ]);
    const [currentColorIdx, setCurrentColorIdx] = useState(0);

    const [size, setSize] = useState(5);
    const [smoothing, setSmoothing] = useState(0.5);

    return (
        <DoodleToolContext.Provider
            value={{
                colorList,
                setColorList,
                currentColor: colorList[currentColorIdx],
                currentColorIdx,
                setCurrentColorIdx,
                size,
                setSize,
                smoothing,
                setSmoothing,
            }}
        >
            {children}
        </DoodleToolContext.Provider>
    );
}

export function useDoodleToolContext() {
    return useContext(DoodleToolContext);
}
