import { useCallback, useEffect } from "react";

import { Overlay, OverlayContent } from "../common/overlay";
import { useImageEditorContext } from "./context";

import { useWorker } from "components/context/viewer/useWorkerContext";
import { useEditorContext } from "components/editor/context";

type ImageOverlayProps = {
    outline?: JSX.Element;
    children?: JSX.Element;
};

export function ImageOverlay({ outline, children }: ImageOverlayProps) {
    useImageSnipOverlay();
    return (
        <Overlay>
            <OverlayContent>{children}</OverlayContent>
            {outline}
        </Overlay>
    );
}

/** Render an image snip on the page
 * @param snip - The image snip to render
 */
function useImageSnipOverlay() {
    const { overlayWorker } = useWorker(0);
    const { activeImgSnip } = useImageEditorContext();
    const { overlayRect } = useEditorContext();

    const render_snip = useCallback(
        (ctx) => {
            activeImgSnip?.render(ctx);
        },
        [activeImgSnip],
    );

    useEffect(() => {
        if (!activeImgSnip) return;
        activeImgSnip.overlay = true;
        overlayWorker.add(render_snip);
        return () => {
            activeImgSnip.overlay = false;
            overlayWorker.remove(render_snip);
        };
    }, [
        activeImgSnip,
        overlayRect.x,
        overlayRect.y,
        overlayWorker,
        render_snip,
    ]);

    return null;
}
