import { useCallback, useEffect } from "react";

import { useMoveToolContext } from "./context";

import { useEditorContext } from "components/editor/context";

export function ZoomHandler() {
    const { pageWrappersRef } = useEditorContext();
    const { setZoom } = useMoveToolContext();

    const onMouseWheel = useCallback(
        (e: WheelEvent, idx: number) => {
            console.log("onMouseWheel", e);
            e.preventDefault();
            e.stopPropagation();
            setZoom(idx, (prev) => prev + e.deltaY / 1000);
        },
        [setZoom],
    );

    useEffect(() => {
        const pageElements = [];
        pageWrappersRef.current.forEach((value) => {
            pageElements.push(value);
        });

        const handlers = pageElements.map((value, idx) => {
            return (e: WheelEvent) => onMouseWheel(e, idx);
        });

        handlers.forEach((handler, idx) => {
            pageElements[idx].addEventListener("wheel", handler);
        });

        return () => {
            handlers.forEach((handler, idx) => {
                pageElements[idx].removeEventListener("wheel", handler);
            });
        };
    }, [onMouseWheel, pageWrappersRef]);

    return null;
}
