import DragMove from "../common/drag";
import { Help, HelpDescription, HelpHeader } from "../common/help";
import {
    Overlay,
    OverlayContent,
    OverlayOutline,
    OverlayPlaceButton,
    useSnipOverlay,
} from "../common/overlay";
import { Toggle } from "../common/toggle";
import { ToolComponents, ToolToggleProps } from "../types";
import { PlacementContextProvider, usePlacementContext } from "./context";
import Icon from "./icon";
import PlacementSubMenu from "./submenu";

import stylesCommon from "../common/toggle.module.scss";

function PlacementToggle(props: ToolToggleProps) {
    const { activeSnip } = usePlacementContext();
    // this tool only works with an active image snip
    if (!activeSnip) {
        return null;
    }
    return (
        <Toggle
            label="Placement"
            icon={<Icon className={stylesCommon.icon} />}
            {...props}
        />
    );
}

function PlacementHelp() {
    return (
        <Help>
            <HelpHeader>
                <span>Placement</span>
                <Icon
                    className={stylesCommon.icon}
                    style={{
                        fill: "transparent",
                    }}
                />
            </HelpHeader>
            <HelpDescription>
                <p>
                    Using this tool you place, move, rotate, and mirror the
                    currently selected snippet. Use the <kbd>Place</kbd> button
                    to permanently place the snippet on the current page.
                </p>
            </HelpDescription>
        </Help>
    );
}

/** The overlay renders
 * a wrapper around the currently
 * selected snip. And allow to move
 * and rotate the snip.
 */
function PlacementOverlay() {
    const { activeSnip, currentOverlayWorker, move, placeOnPage } =
        usePlacementContext();

    useSnipOverlay(activeSnip, currentOverlayWorker);

    return (
        <Overlay>
            <OverlayOutline>
                <OverlayPlaceButton onPlace={placeOnPage} />
            </OverlayOutline>
            <OverlayContent>
                <DragMove
                    className="w-100 h-100 position-absolute"
                    onDragMove={(e) => {
                        move(e.movementX, e.movementY);
                    }}
                ></DragMove>
            </OverlayContent>
        </Overlay>
    );
}

const PlacementTool: ToolComponents = {
    name: "placement" as const,
    Toggle: PlacementToggle,
    Help: PlacementHelp,
    Submenu: PlacementSubMenu,
    Overlay: PlacementOverlay,
    ContextProvider: PlacementContextProvider,
};

export default PlacementTool;
