"use client";
import { useState } from "react";
import { BsArrowCounterclockwise } from "react-icons/bs";

import { InputProps } from "./inputs/base";

import styles from "./Form.module.scss";

export function WrapperInputs({
    children,
    style = {},
    onReset = undefined,
    className = undefined,
    disabled = false,
    ...props
}: {
    children: React.ReactNode;
    onReset?: () => void;
    style?: React.CSSProperties;
    className?: string;
    disabled?: boolean;
    props?: React.HTMLAttributes<HTMLDivElement>;
}) {
    const [transition, setTransition] = useState(false);

    return (
        <div className={className} style={style}>
            <div
                className={styles.inputField + " form-outline"}
                data-withreset={onReset ? "true" : "false"}
                {...props}
            >
                {children}
                {onReset && (
                    <button
                        className={"btn " + styles.reset}
                        onClick={() => {
                            // add value to event
                            onReset();
                            setTransition(true);
                            setTimeout(() => {
                                setTransition(false);
                            }, 500);
                        }}
                        disabled={disabled}
                        type="button"
                    >
                        <BsArrowCounterclockwise data-active={transition} />
                    </button>
                )}
            </div>
        </div>
    );
}

export function SwitchInput({
    value,
    label,
    style = {},
    name = "switch",
    onInput = undefined,
    onReset = undefined,
}: InputProps & { name?: string }) {
    return (
        <WrapperInputs style={style} onReset={onReset}>
            <input
                className={"w-100 form-control form__input"}
                placeholder=" "
                type="checkbox"
                autoComplete="off"
                checked={value === "true"}
                name={name}
                onChange={onInput}
            />
            <label htmlFor={name}>{label}</label>
        </WrapperInputs>
    );
}
