import React, { useEffect, useRef, useState } from "react";
import { Dropdown, FormControl } from "react-bootstrap";

const SearchableDropdown = ({
    options,
    onSelect,
}: {
    options: { label: string; value: string }[];
    onSelect: (option: { label: string; value: string }) => void;
}) => {
    const [filteredOptions, setFilteredOptions] = useState(options);
    const [searchTerm, setSearchTerm] = useState("");
    const searchRef = useRef(null);

    useEffect(() => {
        setFilteredOptions(options);
    }, [options]);

    const handleSearch = (e) => {
        const searchTerm = e.target.value.toLowerCase();
        const filteredOptions = options.filter((option) =>
            option.label.toLowerCase().includes(searchTerm),
        );
        setSearchTerm(searchTerm);
        setFilteredOptions(filteredOptions);
    };

    const handleSelect = (option) => {
        onSelect(option);
        setSearchTerm("");
        setFilteredOptions(options);
        searchRef.current.value = "";
    };

    return (
        <Dropdown>
            <Dropdown.Toggle variant="secondary">
                Select an option
            </Dropdown.Toggle>
            <Dropdown.Menu>
                <FormControl
                    type="text"
                    placeholder="Search..."
                    onChange={handleSearch}
                    ref={searchRef}
                />
                {filteredOptions.map((option) => (
                    <Dropdown.Item
                        key={option.value}
                        active={option.label === searchTerm}
                        onClick={() => handleSelect(option)}
                    >
                        {option.label}
                    </Dropdown.Item>
                ))}
            </Dropdown.Menu>
        </Dropdown>
    );
};

export default SearchableDropdown;
