import { ArraySnip } from "@snip/snips/general/array";
import { LocalPage } from "../localPage";
import { BaseSnip } from "@snip/snips/general/base";

class DummySnip extends BaseSnip {
    height: number;
    width: number;
    type = "dummy";
    constructor(id) {
        super({
            id,
            x: 0,
            y: 0,
            book_id: 1,
        });
    }

    render() {}
}

describe("LocalPage", () => {
    let page: LocalPage;
    const snip1: DummySnip = new DummySnip(1);
    const snip2: DummySnip = new DummySnip(2);

    beforeEach(() => {
        page = new LocalPage({
            id: 1,
            book_id: 1,
            page_number: 1,
            created: new Date(),
            last_updated: new Date(),
            background_type_id: null,
            snips: [snip1],
        });
    });

    test("should add a snip", () => {
        page.add_snip(snip2);
        expect(page.get_snip_by_id(snip2.id)).toEqual(snip2);

        const arraySnip = new ArraySnip({
            id: 3,
            x: 0,
            y: 0,
            snips: [snip1, snip2],
            book_id: 1,
        });

        page.add_snip(arraySnip);

        const arraySnip2 = new ArraySnip({
            id: 4,
            x: 0,
            y: 0,
            snips: [snip1, snip2],
            book_id: 1,
        });
        page.add_snip(arraySnip2);

        page.add_snip(snip1);
    });

    test("should remove a snip", () => {
        page.remove_snip(snip1.id);
    });

    test("should update a snip", () => {
        const updatedSnip: DummySnip = new DummySnip(1);
        page.update_snip(updatedSnip);
    });

    test("should get a snip by id", () => {
        const retrievedSnip = page.get_snip_by_id(snip1.id);
        expect(retrievedSnip).toEqual(snip1);
    });

    test("should get a snip at coordinates", () => {
        const snipAtCoords = page.get_snip_at([0, 0]);
        expect(snipAtCoords).toBe(snip1);

        page.remove_snip(snip1.id);
        const snipAtCoords2 = page.get_snip_at([0, 0]);
        expect(snipAtCoords2).toBe(null);
    });

    test("to_data", () => {
        const data = page.to_data();
        expect(data).toEqual({
            id: 1,
            book_id: 1,
            page_number: 1,
            created: page.created,
            last_updated: page.last_updated,
            background_type_id: null,
        });
    });
});
