import { readFileSync } from "node:fs";

import { NotFoundError } from "@snip/database/errors";

import { mockConfig } from "./mockConfig";
// Mock the loadJsonFile method for testing
jest.mock("@snip/database", () => {
    return {
        page: {
            getById: async (id: string) => {
                if (parseInt(id) == 9999) {
                    throw new NotFoundError("Page", 9999);
                }
                const data = readFileSync(
                    __dirname + "/data/pageData.json",
                    "utf8",
                );
                return JSON.parse(data);
            },
            getFirstByBookId: jest.fn().mockResolvedValue({ id: 123 }),
            getCoverByBookId: async (id: number) => {
                const data = readFileSync(
                    __dirname + "/data/pageData.json",
                    "utf8",
                );
                return JSON.parse(data);
            },
        },
        snip: {
            getByPageId: async () => {
                const data = readFileSync(
                    __dirname + "/data/snips.json",
                    "utf8",
                );
                return JSON.parse(data);
            },
        },
        permission: {
            getByUserAndPageIdReduced: async (
                user_id: number,
                page_id: number,
            ) => {
                if (page_id == 9999) {
                    return {
                        pRead: false,
                    };
                }
                return {
                    pRead: true,
                };
            },
            getByUserAndBookReduced: async (
                user_id: number,
                book_id: number,
            ) => {
                return {
                    pRead: true,
                };
            },
        },
    };
});

jest.mock("@snip/database/sql.connection", () => {
    return {
        pool_data: jest.fn(),
        pool_permissions: jest.fn(),
    };
});

jest.mock("fast-glob", () => {
    return {
        glob: async (query: string) => {
            // Test 2 sizes
            if (query.includes(".pdf")) {
                return ["1400.pdf"];
            }
            if (query.includes(".jpeg")) {
                return ["200.jpeg"];
            }
            if (query.includes(".webp")) {
                return ["200.webp"];
            }
            return [];
        },
    };
});

jest.mock("fs", () => {
    return {
        ...jest.requireActual("fs"),

        createReadStream: (path: string) => {
            if (path.includes(".pdf")) {
                return jest
                    .requireActual("fs")
                    .createReadStream(__dirname + "/data/test.pdf");
            }
            if (path.includes(".jpeg")) {
                return jest
                    .requireActual("fs")
                    .createReadStream(__dirname + "/data/test.jpeg");
            }
        },
    };
});

jest.mock("@snip/utils/config", () => {
    return {
        config: {
            RENDER: {
                ...jest.requireActual("@snip/utils/config").config.RENDER,
                DIR: __dirname + "/data/tmp",
            },
        },
    };
});

// Moock session
jest.mock("@snip/auth/session", () => {
    return {
        getSession: async () => {
            const ret = {
                user: {
                    id: 1,
                },
            } as any;
            if (mockConfig.force_api_session) {
                return {
                    api: "test",
                };
            }
            if (mockConfig.session) {
                return ret;
            } else {
                return {};
            }
        },
    };
});

// Mock fetch
global.fetch = jest.fn(
    () =>
        Promise.resolve({
            text: () => {
                //wait 2 seconds
                return new Promise((resolve) => {
                    setTimeout(() => {
                        resolve("test");
                    }, 2000);
                });
            },
        }),
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
) as any;
