import {
    type Namespace,
    RemoteSocket as RemoteSocketIo,
    Server,
    type Socket as SocketIo,
} from "socket.io";

import { type ParsedPermissionACLData } from "@snip/auth/book_permissions";
import { SnipSessionData } from "@snip/auth/session";
import { ID } from "@snip/database/types";
// Extend socket to include book_id, id and perms
// This is set in the the book_authenticate middleware
export interface Socket extends SocketIo {
    book_id: ID;
    perms: ParsedPermissionACLData;
    session: SnipSessionData;
    data: {
        id: ID; //user id
        auth_method: "user" | "ui_token";
        email: string;
        allowedPages: ID[];
    };
}
export interface SocketData {
    book_nsp: Namespace;
    socket: Socket;
    server: Server;
}

interface ServerToClientEvents {
    // Allow any event names
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    [k: string]: (val: any) => any;
}

export type RemoteSocket = RemoteSocketIo<ServerToClientEvents, Socket["data"]>;

export interface User {
    id: ID;
    email: string;
    page_ids: Set<ID> | ID[];
}

export interface ExtendedError extends Error {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    data?: any;
}
export type SocketNextFkt = (err?: ExtendedError) => void;

declare module "socket.io" {
    interface Socket {
        session: SnipSessionData;
        book_id: ID;
        perms: ParsedPermissionACLData;
    }
}
