import { exec } from "child_process";
import mariadb from "mariadb";

export async function setupDatabase() {
    // check if TEST_PORT variable is set
    let port = process.env.TEST_PORT;
    if (!port) {
        console.warn("TEST_PORT not set! Using default port 5432.");
        port = "8652";
    }

    // Check if database is already running by ping
    const pool = mariadb.createPool({
        host: "test_mariadb",
        user: "snip",
        password: "snip",
        port: parseInt(port),
    });

    // Ping the database
    try {
        await pool.getConnection();
        console.log("Database is running!");
        return;
    } catch (e) {
        console.error(e);
        console.error("Database is not running. Starting database...");
    }

    await execute("docker compose up -d");
    // Wait for 2 seconds to allow the database to start
    await new Promise((resolve) => setTimeout(resolve, 2000));

    // Wait for the migration container to finish
    await execute("docker wait test_migration");

    // Await delete of all data
}

export async function teardownDatabase() {
    // Stop your Docker containers or any other teardown logic
    await execute("docker compose down");
}

const execute = async (string: string) => {
    await new Promise((resolve, reject) => {
        exec(
            string,
            { cwd: __dirname + "/docker" },
            (error, stdout: string, stderr: string) => {
                if (error) {
                    console.error(stderr);
                    reject(error);
                } else {
                    resolve(stdout);
                }
            },
        );
    });
};
